@@ -35,7 +35,7 @@ ImbalancedClassificationAlgorithm <- R6::R6Class("ImbalancedClassificationAlgori
 
       #Test jar file
       #if(! file.exists(paste0(private$exePath, private$jarName))){
-      if(! file.exists(system.file("exe", private$jarName, package = "RKEELjars"))){
+      if(! file.exists(system.file("exe", private$jarName, package = "RKEEL"))){
         stop(paste0(private$jarName, " doesn't exist under the defined path. Installation error."))
       }
 
@@ -59,7 +59,7 @@ ImbalancedClassificationAlgorithm <- R6::R6Class("ImbalancedClassificationAlgori
         cat("Writed datasets")
 
         #Copy algorithm exe
-        file.copy(system.file("exe", private$jarName, package = "RKEELjars"), paste0(private$mainPath, "/exe/", private$jarName))
+        file.copy(system.file("exe", private$jarName, package = "RKEEL"), paste0(private$mainPath, "/exe/", private$jarName))
 
         #Create results dir
         dir.create(paste0(private$mainPath, "/results/", private$algorithmName, ".", private$dataName))
@@ -73,7 +73,12 @@ ImbalancedClassificationAlgorithm <- R6::R6Class("ImbalancedClassificationAlgori
         private$writeKeelConfig()
 
         cat(private$mainPath)
-
+        
+        #Change to old current working directory after finishing the function
+        # even if an error occurs
+        wdPath <- getwd()
+        on.exit(setwd(wdPath))
+        
         #Change work directory to execute .jar
         setwd(paste0(private$mainPath, "/scripts/"))
         if(grepl("windows", tolower(Sys.info()[1]))) {
