@@ -35,7 +35,7 @@ PreprocessAlgorithm <- R6::R6Class("PreprocessAlgorithm",
 
       #Test jar file
       #if(! file.exists(paste0(private$exePath, private$jarName))){
-      if(! file.exists(system.file("exe", private$jarName, package = "RKEELjars"))){
+      if(! file.exists(system.file("exe", private$jarName, package = "RKEEL"))){
         stop(paste0(private$jarName, " doesn't exist under the defined path. Installation error."))
       }
 
@@ -60,10 +60,10 @@ PreprocessAlgorithm <- R6::R6Class("PreprocessAlgorithm",
         }
 
         #Copy algorithm exe
-        file.copy(system.file("exe", private$jarName, package = "RKEELjars"), paste0(private$mainPath, "/exe/", private$jarName))
+        file.copy(system.file("exe", private$jarName, package = "RKEEL"), paste0(private$mainPath, "/exe/", private$jarName))
 
         #Copy RunKeel exe
-        file.copy(system.file("exe", "RunKeel.jar", package = "RKEELjars"), paste0(private$mainPath, "/scripts/", "RunKeel.jar"))
+        file.copy(system.file("exe", "RunKeel.jar", package = "RKEEL"), paste0(private$mainPath, "/scripts/", "RunKeel.jar"))
 
         #Create results dir
         #dir.create(paste0(private$mainPath, "/results/", private$algorithmName, ".", private$dataName))
@@ -76,9 +76,11 @@ PreprocessAlgorithm <- R6::R6Class("PreprocessAlgorithm",
         dir.create(paste0(private$mainPath, "/scripts/", private$algorithmName, "/", private$dataName))
         private$writeKeelConfig()
 
-        #Change work directory to execute .jar
         #Change work directory to execute .jar
         wdPath <- getwd()
+        #Change to old current working directory after finishing the function
+        # even if an error occurs
+        on.exit(setwd(wdPath))
 
         #Manage options to java command line
         if(missing(javaOptions)){
